@@ -3,7 +3,7 @@
 # Download and install Macports. For use in CI.
 
 # Version of Macports to install
-VERSION=2.7.2
+VERSION=2.8.1
 
 if [ "$(uname)" != "Darwin" ]; then
   printf 'this script is only intended to run on macOS\n' >&2
@@ -21,13 +21,8 @@ TMP=$(mktemp -d)
 cd "${TMP}"
 
 # Download
-curl --retry 3 -O https://distfiles.macports.org/MacPorts/MacPorts-${VERSION}.tar.bz2
+curl --retry 3 --location --no-progress-meter -O \
+  https://github.com/macports/macports-base/releases/download/v${VERSION}/MacPorts-${VERSION}-13-Ventura.pkg
 
-# Decompress
-tar xf MacPorts-${VERSION}.tar.bz2
-cd MacPorts-${VERSION}
-
-# Configure and install
-./configure
-make
-sudo make install
+# Install
+sudo installer -package MacPorts-${VERSION}-13-Ventura.pkg -target /
