@@ -1,20 +1,20 @@
-#include <cstddef>
 #include "has-start-state.h"
+#include <cstddef>
 #include <rumur/rumur.h>
 
 using namespace rumur;
 
-namespace { class Finder : public ConstTraversal {
+namespace {
+class Finder : public ConstTraversal {
 
- public:
+public:
   bool result = false;
 
-  void visit_startstate(const StartState&) final {
-    result = true;
-  }
+  void visit_startstate(const StartState &) final { result = true; }
 
   virtual ~Finder() = default;
-}; }
+};
+} // namespace
 
 bool has_start_state(const Model &m) {
   Finder f;
